@@ -454,14 +454,17 @@ bool PhysicalFont::getExactGlyphBox (int c, GlyphMetrics &metrics, bool vertical
 	BoundingBox charbox;
 	if (!getExactGlyphBox(c, charbox, cb))
 		return false;
-	if ((metrics.wl = -charbox.minX()) < 0) metrics.wl=0;
-	if ((metrics.wr = charbox.maxX()) < 0)  metrics.wr=0;
-	if ((metrics.h = charbox.maxY()) < 0)   metrics.h=0;
-	if ((metrics.d = -charbox.minY()) < 0)  metrics.d=0;
+	metrics.wl = -charbox.minX();
+	metrics.wr = charbox.maxX();
+	metrics.h = charbox.maxY();
+	metrics.d = -charbox.minY();
 	if (vertical) {  // vertical text orientation
 		if (verticalLayout()) {  // font designed for vertical layout?
-			metrics.wl = metrics.wr = (metrics.wl+metrics.wr)/2;
-			metrics.d += metrics.h;
+			double wl = max(0.0, metrics.wl);
+			double wr = max(0.0, metrics.wr);
+			double h = max(0.0, metrics.h);
+			metrics.wl = metrics.wr = (wl+wr)/2;
+			metrics.d += h;
 			metrics.h = 0;
 		}
 		else {
