@@ -2,7 +2,7 @@
 ** PSInterpreter.cpp                                                    **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2022 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2023 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -27,7 +27,6 @@
 #include "FileSystem.hpp"
 #include "InputReader.hpp"
 #include "Message.hpp"
-#include "PSFilter.hpp"
 #include "PSInterpreter.hpp"
 #include "SignalHandler.hpp"
 #include "utility.hpp"
@@ -67,7 +66,8 @@ void PSInterpreter::init () {
 			// as of GS 9.56.0. Since dvisvgm relies on the old PS-based interpreter for its
 			// PDF support, we try to disable the new one.
 			// https://www.ghostscript.com/doc/9.56.0/Use.htm#PDF_switches
-			if (gsrev >= 9560)
+			// As of GS 10.02.0, option NEWPDF has been deprecated and has no effect any longer.
+			if (gsrev >= 9560 && gsrev < 10020)
 				gsargs.emplace_back("-dNEWPDF=false");
 		}
 		_gs.init(gsargs.size(), gsargs.data(), this);
@@ -126,15 +126,6 @@ bool PSInterpreter::execute (const char *str, size_t len, bool flush) {
 		complete = true;
 	}
 
-	if (_filter && _filter->active()) {
-		PSFilter *filter = _filter;
-		_filter = nullptr;       // prevent recursion when filter calls execute()
-		filter->execute(str, len);
-		if (filter->active())    // filter still active after execution?
-			_filter = filter;
-		return complete;
-	}
-
 	// feed Ghostscript with code chunks that are not larger than 64KB
 	// => see documentation of gsapi_run_string_foo()
 	const char *p=str;
