@@ -31,7 +31,7 @@
 #include "PSInterpreter.hpp"
 #include "Opacity.hpp"
 #include "PSPattern.hpp"
-#include "PSPreviewFilter.hpp"
+#include "PSPreviewHandler.hpp"
 #include "SpecialHandler.hpp"
 
 class PSPattern;
@@ -91,12 +91,13 @@ class PsSpecialHandler : public SpecialHandler, protected PSActions {
 	public:
 		PsSpecialHandler ();
 		~PsSpecialHandler () override;
-		const char* name () const override {return "ps";}
-		const char* info () const override {return "dvips PostScript specials";}
-		std::vector<const char*> prefixes() const override;
 		void preprocess (const std::string &prefix, std::istream &is, SpecialActions &actions) override;
 		bool process (const std::string &prefix, std::istream &is, SpecialActions &actions) override;
-		void setDviScaleFactor (double dvi2bp) override {_previewFilter.setDviScaleFactor(dvi2bp);}
+		const char* info () const override {return "dvips PostScript specials";}
+		const char* name () const override {return handlerName();}
+		static const char* handlerName ()  {return "ps";}
+		std::vector<const char*> prefixes () const override;
+		void setDviScaleFactor (double dvi2bp) override {_previewHandler.setDviScaleFactor(dvi2bp);}
 		void enterBodySection ();
 		PSInterpreter& psInterpreter () {return _psi;}
 
@@ -179,7 +180,7 @@ class PsSpecialHandler : public SpecialHandler, protected PSActions {
 		PSInterpreter _psi;
 		PDFHandler _pdfHandler;
 		SpecialActions *_actions=nullptr;
-		PSPreviewFilter _previewFilter;    ///< filter to extract information generated by the preview package
+		PSPreviewHandler _previewHandler;  ///< extracts information generated by the preview package
 		PsSection _psSection=PS_NONE;      ///< current section processed (nothing yet, headers, or body specials)
 		XMLElement *_xmlnode=nullptr;      ///< if != 0, created SVG elements are appended to this node
 		XMLElement *_savenode=nullptr;     ///< pointer to temporaryly store _xmlnode
