@@ -2,7 +2,7 @@
 ** EmSpecialTest.cpp                                                    **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2022 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2023 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -52,7 +52,7 @@ class EmSpecialTest : public ::testing::Test {
 
 /*				void write (ostream &os) const {
 					os << "page: " << page << '\n'
-						<< "bbox: " << bbox.toSVGViewBox() << '\n';
+						<< "bbox: " << bbox.svgViewBoxString() << '\n';
 				} */
 
 			private:
